=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-01-21 11:30:15 +0000
+++ bzrlib/tests/__init__.py	2006-01-23 01:40:28 +0000
@@ -65,8 +65,10 @@
                       ]
 def packages_to_test():
     import bzrlib.tests.blackbox
+    import bzrlib.tests.branch_implementations
     return [
-            bzrlib.tests.blackbox
+            bzrlib.tests.blackbox,
+            bzrlib.tests.branch_implementations,
             ]
 
 
@@ -812,8 +814,6 @@
                    'bzrlib.tests.test_workingtree',
                    'bzrlib.tests.test_xml',
                    ]
-    test_branch_implementations = [
-        'bzrlib.tests.test_branch_implementations']
     test_transport_implementations = [
         'bzrlib.tests.test_transport_implementations']
 
@@ -830,21 +830,7 @@
     loader = TestLoader()
     from bzrlib.transport import TransportTestProviderAdapter
     adapter = TransportTestProviderAdapter()
-    for mod_name in test_transport_implementations:
-        mod = _load_module_by_name(mod_name)
-        for test in iter_suite_tests(loader.loadTestsFromModule(mod)):
-            suite.addTests(adapter.adapt(test))
-    from bzrlib.branch import BranchTestProviderAdapter
-    adapter = BranchTestProviderAdapter(
-        bzrlib.transport.local.LocalRelpathServer,
-        # None here will cause a readonly decorator to be created
-        # by the TestCaseWithTransport.get_readonly_transport method.
-        None,
-        bzrlib.branch.BzrBranchFormat._formats.values())
-    for mod_name in test_branch_implementations:
-        mod = _load_module_by_name(mod_name)
-        for test in iter_suite_tests(loader.loadTestsFromModule(mod)):
-            suite.addTests(adapter.adapt(test))
+    adapt_modules(test_transport_implementations, adapter, loader, suite)
     for mod_name in testmod_names:
         mod = _load_module_by_name(mod_name)
         suite.addTest(loader.loadTestsFromModule(mod))
@@ -860,6 +846,14 @@
     return suite
 
 
+def adapt_modules(mods_list, adapter, loader, suite):
+    """Adapt the modules in mods_list using adapter and add to suite."""
+    for mod_name in mods_list:
+        mod = _load_module_by_name(mod_name)
+        for test in iter_suite_tests(loader.loadTestsFromModule(mod)):
+            suite.addTests(adapter.adapt(test))
+
+
 def _load_module_by_name(mod_name):
     parts = mod_name.split('.')
     module = __import__(mod_name)

=== added directory 'bzrlib/tests/branch_implementations'
=== added file 'bzrlib/tests/branch_implementations/__init__.py'
--- bzrlib/tests/branch_implementations/__init__.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/branch_implementations/__init__.py	2006-01-23 01:40:28 +0000
@@ -0,0 +1,44 @@
+# Copyright (C) 2005 by Canonical Ltd
+# -*- coding: utf-8 -*-
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+
+"""Branch implementation tests for bzr.
+
+These test the conformance of all the branch variations to the expected API.
+Specific tests for individual formats are in the tests/test_branch file 
+rather than in tests/branch_implementations/*.py.
+"""
+
+from bzrlib.branch import BranchTestProviderAdapter, BzrBranchFormat
+from bzrlib.tests import adapt_modules, TestLoader, TestSuite
+from bzrlib.tests import TestCaseInTempDir, BzrTestBase
+from bzrlib.transport.local import LocalRelpathServer
+
+def test_suite():
+    result = TestSuite()
+    test_branch_implementations = [
+        'bzrlib.tests.branch_implementations.test_branch',
+        ]
+    adapter = BranchTestProviderAdapter(
+        LocalRelpathServer,
+        # None here will cause a readonly decorator to be created
+        # by the TestCaseWithTransport.get_readonly_transport method.
+        None,
+        BzrBranchFormat._formats.values())
+    loader = TestLoader()
+    adapt_modules(test_branch_implementations, adapter, loader, result)
+    return result

=== renamed file 'bzrlib/tests/test_branch_implementations.py' => 'bzrlib/tests/branch_implementations/test_branch.py'
